==> gimp-2.7.0.tar.bz2: gimp-2.7.0/libgimpconfig/gimpconfig-deserialize.h <==
/* LIBGIMP - The GIMP Library
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * Object properties deserialization routines
 * Copyright (C) 2001-2002  Sven Neumann <sven@gimp.org>
 *
 * This library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#ifndef __GIMP_CONFIG_DESERIALIZE_H__
#define __GIMP_CONFIG_DESERIALIZE_H__

G_BEGIN_DECLS

/* For information look into the C source or the html documentation */


gboolean    gimp_config_deserialize_properties (GimpConfig *config,
                                                GScanner   *scanner,
                                                gint        nest_level);
GTokenType  gimp_config_deserialize_property   (GimpConfig *config,
                                                GScanner   *scanner,
                                                gint        nest_level);


G_END_DECLS

#endif /* __GIMP_CONFIG_DESERIALIZE_H__ */

==> gimp_2.8.16.orig.tar.bz2: gimp-2.8.16/libgimpconfig/gimpconfig-deserialize.h <==
/* LIBGIMP - The GIMP Library
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * Object properties deserialization routines
 * Copyright (C) 2001-2002  Sven Neumann <sven@gimp.org>
 *
 * This library is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

#if !defined (__GIMP_CONFIG_H_INSIDE__) && !defined (GIMP_CONFIG_COMPILATION)
#error "Only <libgimpconfig/gimpconfig.h> can be included directly."
#endif

#ifndef __GIMP_CONFIG_DESERIALIZE_H__
#define __GIMP_CONFIG_DESERIALIZE_H__

G_BEGIN_DECLS

/* For information look into the C source or the html documentation */


gboolean    gimp_config_deserialize_properties (GimpConfig *config,
                                                GScanner   *scanner,
                                                gint        nest_level);
GTokenType  gimp_config_deserialize_property   (GimpConfig *config,
                                                GScanner   *scanner,
                                                gint        nest_level);


G_END_DECLS

#endif /* __GIMP_CONFIG_DESERIALIZE_H__ */
